@@ -14,14 +14,14 @@ import uuid
 
 # Third party imports
 from intervaltree import IntervalTree
-from pkg_resources import parse_version
+from packaging.version import parse
 from qtpy import PYSIDE2, PYSIDE_VERSION
 from qtpy.QtCore import Qt, QTimer, Signal, Slot
 from qtpy.QtWidgets import QTreeWidgetItem, QTreeWidgetItemIterator
 
 # Local imports
 from spyder.api.config.decorators import on_conf_change
-from spyder.config.base import _
+from spyder.api.translations import _
 from spyder.utils.icon_manager import ima
 from spyder.plugins.completion.api import SymbolKind, SYMBOL_KIND_ICON
 from spyder.utils.qthelpers import set_item_user_text
@@ -266,6 +266,7 @@ class OutlineExplorerTreeWidget(OneColumnTree):
         self._current_editor = None
         self._languages = []
         self.is_visible = False
+        self._symbols_expanded_state: dict[str, bool] = {}
 
         self.currentItemChanged.connect(self.selection_switched)
         self.itemExpanded.connect(self.tree_item_expanded)
@@ -432,17 +433,13 @@ class OutlineExplorerTreeWidget(OneColumnTree):
         logger.debug(f"Set current editor to file {editor.fname}")
         self.current_editor = editor
 
-        # Update tree with currently stored info or require symbols if
-        # necessary.
         if (
-            editor.get_language().lower() in self._languages
-            and len(self.editor_tree_cache[editor_id]) == 0
+            self.is_visible
+            and (editor.get_language().lower() in self._languages)
+            and not editor.is_tree_updated
         ):
             if editor.info is not None:
-                if update:
-                    self.update_editor(editor.info)
-            elif editor.is_cloned:
-                editor.request_symbols()
+                self.update_editor(editor.info)
 
     def register_editor(self, editor):
         """
@@ -542,15 +539,6 @@ class OutlineExplorerTreeWidget(OneColumnTree):
                 f"Don't update tree of file {editor.fname} because plugin is "
                 f"not visible"
             )
-
-            # This keeps track of files that have been modified while the
-            # Outline is hidden. That way we'll only update those when the user
-            # makes it visible.
-            language = editor.get_language().lower()
-            if not self.starting[language]:
-                if editor.is_tree_updated:
-                    editor.is_tree_updated = False
-
             self.sig_hide_spinner.emit()
             return
 
@@ -610,6 +598,11 @@ class OutlineExplorerTreeWidget(OneColumnTree):
             symbol_end = symbol_range['end']['line']
             symbol_repr = SymbolStatus(symbol_name, symbol_kind,
                                        (symbol_start, symbol_end), None)
+            if self._symbols_expanded_state.get(symbol_name):
+                symbol_repr.status = True
+            else:
+                self._symbols_expanded_state[symbol_name] = False
+                symbol_repr.status = False
             tree_info.append((symbol_start, symbol_end + 1, symbol_repr))
 
         tree = IntervalTree.from_tuples(tree_info)
@@ -621,8 +614,7 @@ class OutlineExplorerTreeWidget(OneColumnTree):
         if not must_update:
             # Compare with current tree to check if it's necessary to update
             # it.
-            changes = tree - current_tree
-            if tree and len(changes) == 0:
+            if tree == current_tree:
                 logger.debug(
                     f"Current and new trees for file {editor.fname} are the "
                     f"same, so no update is necessary"
@@ -661,7 +653,7 @@ class OutlineExplorerTreeWidget(OneColumnTree):
             if self.current_editor is editor:
                 self.current_editor = None
 
-            logger.debug(f"Removing tree of file f{editor.fname}")
+            logger.debug(f"Removing tree of file {editor.fname}")
 
             editor_id = self.editor_ids.pop(editor)
             language = editor.get_language().lower()
@@ -731,7 +723,7 @@ class OutlineExplorerTreeWidget(OneColumnTree):
         # [1] https://bugreports.qt.io/browse/PYSIDE-74
         # [2] https://codereview.qt-project.org/c/pyside/pyside-setup/+/312945
         update = (
-            (PYSIDE2 and parse_version(PYSIDE_VERSION) <= parse_version("5.15.0"))
+            (PYSIDE2 and parse(PYSIDE_VERSION) <= parse("5.15.0"))
             or (current_ordered_items != new_ordered_items)
         )
         if update:
@@ -785,7 +777,7 @@ class OutlineExplorerTreeWidget(OneColumnTree):
             iterator += 1
         return items
 
-    def activated(self, item):
+    def on_item_activated(self, item):
         """Double-click event"""
         editor_root = self.editor_items.get(
             self.editor_ids.get(self.current_editor))
@@ -814,11 +806,11 @@ class OutlineExplorerTreeWidget(OneColumnTree):
                     break
             break
 
-    def clicked(self, item):
+    def on_item_clicked(self, item):
         """Click event"""
         if isinstance(item, FileRootItem):
             self.root_item_selected(item)
-        self.activated(item)
+        self.on_item_activated(item)
 
     def selection_switched(self, current_item, previous_item):
         if current_item is not None:
@@ -831,10 +823,12 @@ class OutlineExplorerTreeWidget(OneColumnTree):
     def tree_item_collapsed(self, item):
         ref = item.ref
         ref.status = False
+        self._symbols_expanded_state[ref.name] = False
 
     def tree_item_expanded(self, item):
         ref = item.ref
         ref.status = True
+        self._symbols_expanded_state[ref.name] = True
 
     def set_editors_to_update(self, language, reset_info=False):
         """Set editors to update per language."""
